stouputils.continuous_delivery package — stouputils 1.0.18 documentation

# stouputils.continuous_delivery package

## Submodules

- stouputils.continuous_delivery.cd_utils module
  - `load_credentials()`
  - `handle_response()`
- stouputils.continuous_delivery.github module
  - `validate_credentials()`
  - `validate_config()`
  - `handle_existing_tag()`
  - `delete_existing_release()`
  - `delete_existing_tag()`
  - `clean_version()`
  - `version_to_float()`
  - `get_latest_tag()`
  - `get_commits_since_tag()`
  - `generate_changelog()`
  - `create_tag()`
  - `create_release()`
  - `upload_assets()`
  - `upload_to_github()`